==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridActionsBaseDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionButtonDescriptionMetadata } from "./WebGridActionButtonDescriptionMetadata";
import { WebActionStripDescriptionMetadata } from "./WebActionStripDescriptionMetadata";
import { WebGridActionsBaseDirectiveDescription } from "./WebGridActionsBaseDirectiveDescription";
/**
 * @hidden
 */
export let WebGridActionsBaseDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionsBaseDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionsBaseDirectiveDescriptionMetadata.a == null) {
                WebGridActionsBaseDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionsBaseDirectiveDescriptionMetadata.c(WebGridActionsBaseDirectiveDescriptionMetadata.a);
            }
            if (a.j(WebGridActionsBaseDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridActionsBaseDirectiveDescriptionMetadata.a);
            WebGridActionButtonDescriptionMetadata.d(a);
            WebActionStripDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionsBaseDirective");
            a.item("__tagNameWC", "String:igc-grid-action-base-directive");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Buttons", "Array:WebGridActionButtonDescription:GridActionButton");
            a.item("AsMenuItems", "Boolean");
            a.item("Strip", "ExportedType:WebActionStrip");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridActionsBaseDirectiveDescriptionMetadata.b(a);
            a.aa("WebGridActionsBaseDirective", () => new WebGridActionsBaseDirectiveDescription());
            a.z("WebGridActionsBaseDirective", WebGridActionsBaseDirectiveDescriptionMetadata.a);
        }
    }
    WebGridActionsBaseDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionsBaseDirectiveDescriptionMetadata, 'WebGridActionsBaseDirectiveDescriptionMetadata');
    WebGridActionsBaseDirectiveDescriptionMetadata.a = null;
    return WebGridActionsBaseDirectiveDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridActionsBaseDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionButtonDescriptionMetadata } from "./WebGridActionButtonDescriptionMetadata";
import { WebActionStripDescriptionMetadata } from "./WebActionStripDescriptionMetadata";
import { WebGridActionsBaseDirectiveDescription } from "./WebGridActionsBaseDirectiveDescription";
/**
 * @hidden
 */
export let WebGridActionsBaseDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionsBaseDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionsBaseDirectiveDescriptionMetadata.a == null) {
                WebGridActionsBaseDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionsBaseDirectiveDescriptionMetadata.c(WebGridActionsBaseDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebGridActionsBaseDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridActionsBaseDirectiveDescriptionMetadata.a);
            WebGridActionButtonDescriptionMetadata.d(a);
            WebActionStripDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionsBaseDirective");
            a.item("__tagNameWC", "String:igc-grid-action-base-directive");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Buttons", "Array:WebGridActionButtonDescription:GridActionButton");
            a.item("AsMenuItems", "Boolean");
            a.item("Strip", "ExportedType:WebActionStrip");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridActionsBaseDirectiveDescriptionMetadata.b(a);
            a.ac("WebGridActionsBaseDirective", () => new WebGridActionsBaseDirectiveDescription());
            a.ab("WebGridActionsBaseDirective", WebGridActionsBaseDirectiveDescriptionMetadata.a);
        }
    }
    WebGridActionsBaseDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionsBaseDirectiveDescriptionMetadata, 'WebGridActionsBaseDirectiveDescriptionMetadata');
    WebGridActionsBaseDirectiveDescriptionMetadata.a = null;
    return WebGridActionsBaseDirectiveDescriptionMetadata;
})();
